Add [Fontawesome5](https://fontawesome.com/) to your Wagtail project's admin.

- Django >= 3.1.7
- Wagtail >= 2.12.2

## Install

```
pip install wagtail-admin-fontawesome
```

than add `wagtail_admin_fontawesome` to your installed apps.

## Usage

#### ModelAdmin

Use icons on ModelAdmin menu, just set `menu_icon` with your favorite icon of [Fontawesome list](https://fontawesome.com/icons?d=gallery&p=2)
